@@ -28,6 +28,13 @@ from typing import Any, Dict
 
 from ..cli.load_arguments_from_dataclass import extract_fields_from_class
 from ..tests.utils import exitclose_file_creator
+from .cgcnn.core import (
+    CGCNNDataArguments,
+    CGCNNModelArguments,
+    CGCNNSavingArguments,
+    CGCNNTrainingArguments,
+    CGCNNTrainingPipeline,
+)
 from .diffusion.core import (
     DiffusionDataArguments,
     DiffusionForVisionTrainingPipeline,
@@ -166,6 +173,11 @@ TRAINING_PIPELINE_ARGUMENTS_MAPPING = {
         GFlowNetDataArguments,
         GFlowNetModelArguments,
     ),
+    "cgcnn": (
+        CGCNNDataArguments,
+        CGCNNModelArguments,
+        CGCNNTrainingArguments,
+    ),
 }
 
 TRAINING_PIPELINE_MAPPING = {
@@ -180,6 +192,7 @@ TRAINING_PIPELINE_MAPPING = {
     "regression-transformer-trainer": RegressionTransformerTrainingPipeline,
     "diffusion-trainer": DiffusionForVisionTrainingPipeline,
     "gflownet-trainer": GFlowNetTrainingPipeline,
+    "cgcnn": CGCNNTrainingPipeline,
 }
 
 TRAINING_PIPELINE_ARGUMENTS_FOR_MODEL_SAVING = {
@@ -194,6 +207,7 @@ TRAINING_PIPELINE_ARGUMENTS_FOR_MODEL_SAVING = {
     "regression-transformer-trainer": RegressionTransformerSavingArguments,
     "diffusion-trainer": DiffusionSavingArguments,
     "gflownet-trainer": GFlowNetSavingArguments,
+    "cgcnn": CGCNNSavingArguments,
 }
 
 
